***
# PyTrek 9000
***

The original free-and-open Star Trek console game was THE most played game of the day .... back in the 1970's! 

![PyTrek 9000](https://github.com/Python3-Training/PyTrek-9000/blob/master/PyTrek.png)

Originally written in B.A.S.I.C, from C/C++, FORTRAN, C#, Python 2 ... and now Python 3, many have been inspired to re-create, improve, and / or simply experiment with the concept.

So far:

* Converted from Python 2, to Python 3. 

* Changed in-system coordinates to simple 'chess like' (b,4 (etc)) references.

* Added random event Quips – should make the game a tad more ‘NPC’?

* Added that classic sublight / in system propulsion system. Warp speeds engines are now a seperate navigational system.

* Warp speed selection changes game time. (Thanks Loondas!)

* Heavily re-factored for growth, testing, re-use, and maintenance using modern Python.

Video: https://youtu.be/TpmtCLOJ5Uw

Original authors did an excellent job - made the modernization a WHOLE LOT easier!

Feel free to do a 'Kirk here - Kobayashi Maru?

https://www.udemy.com/course/python-1000/ 

Thinking about adding mult-user / networked features? -Then [here is a good video](https://www.oreilly.com/library/view/tcpip-and-udpip/9781484294543/) to assist with those networking 'Py-Spirations.



Enjoy the journey,


-- Randall Nagy

### P.S
Changed the official PyTrek number from 2020 to 9000 to better support age-nostic updates & enhancements. Same for the `Game` Class in PyTrek1.py

To play PyTrek 9000:

```
>>> from PyTrek import PyTrek1
```
-will automaticall run this TUI universal.


## zSupport?
If you want to support the effort, I seek no donations. Instead, simply feel free to purchase one of [my educational](https://www.udemy.com/user/randallnagy2/) or [printed](https://www.amazon.com/Randall-Nagy/e/B08ZJLH1VN?ref=sr_ntt_srch_lnk_1&qid=1660050704&sr=8-1) productions?


